"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const lodash_clone_1 = __importDefault(require("lodash.clone"));
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const metadata_object_1 = __importDefault(require("./metadata.object"));
class EvaluationRecord {
    constructor(evaluator) {
        this.type = "evaluation";
        this.evaluator = lodash_clone_1.default(evaluator);
        this.metadata = new metadata_object_1.default();
        this.modules = {};
    }
    addModuleEvaluation(module, evaluation) {
        var _a, _b, _c, _d;
        const clonedEvaluation = lodash_clonedeep_1.default(evaluation);
        if (clonedEvaluation) {
            switch (module) {
                case "act-rules":
                    this.modules["act-rules"] = clonedEvaluation;
                    break;
                case "wcag-techniques":
                    this.modules["wcag-techniques"] = (clonedEvaluation);
                    break;
                case "best-practices":
                    this.modules["best-practices"] = (clonedEvaluation);
                    break;
            }
            if (module !== "wappalyzer") {
                this.metadata.addPassedResults(((_a = this.modules[module]) === null || _a === void 0 ? void 0 : _a.metadata.passed) || 0);
                this.metadata.addWarningResults(((_b = this.modules[module]) === null || _b === void 0 ? void 0 : _b.metadata.warning) || 0);
                this.metadata.addFailedResults(((_c = this.modules[module]) === null || _c === void 0 ? void 0 : _c.metadata.failed) || 0);
                this.metadata.addInapplicableResults(((_d = this.modules[module]) === null || _d === void 0 ? void 0 : _d.metadata.inapplicable) || 0);
            }
        }
    }
    getFinalReport() {
        return lodash_clonedeep_1.default({
            type: this.type,
            system: this.evaluator,
            metadata: this.metadata.getResults(),
            modules: this.modules,
        });
    }
}
module.exports = EvaluationRecord;
//# sourceMappingURL=evaluationRecord.object.js.map